# cli.py
import sys
import os

# Import from translator module
try:
    from .translator import run, compile_to_py
except ImportError:
    from translator import run, compile_to_py

def main():
    if len(sys.argv) < 2:
        print("استخدام:")
        print("  arabicpy <file.apy>             # تشغيل الملف")
        print("  arabicpy -c <file.apy> <file.py>  # تجميع إلى Python")
        print("  arabicpy --translate <file.apy>   # عرض الكود المترجم")
        return
    
    if sys.argv[1] == "-c" or sys.argv[1] == "--compile":
        if len(sys.argv) < 4:
            print("اكتب: arabicpy -c <file.apy> <output.py>")
            return
        compile_to_py(sys.argv[2], sys.argv[3])
    
    elif sys.argv[1] == "--translate" or sys.argv[1] == "-t":
        if len(sys.argv) < 3:
            print("اكتب: arabicpy --translate <file.apy>")
            return
        result = run(sys.argv[2], execute=False)
        print("الكود المترجم:")
        print("-" * 50)
        print(result)
    
    elif sys.argv[1] == "--help" or sys.argv[1] == "-h":
        print("أداة Python العربية - ترجمة Python إلى العربية")
        print("\nأوامر:")
        print("  arabicpy <file.apy>             تشغيل ملف Python عربي")
        print("  arabicpy -c <in.apy> <out.py>   تجميع إلى Python عادي")
        print("  arabicpy -t <file.apy>          عرض الترجمة")
        print("  arabicpy --help                 عرض هذه المساعدة")
    
    else:
        # Use the imported run function
        run(sys.argv[1])

if __name__ == "__main__":
    main()