# translator_enhanced.py
KEYWORDS = {
    # Python Keywords
    "خطأ": "False",
    "لا_شيء": "None",
    "صحيح": "True",
    "و": "and",
    "مثل": "as",
    "تأكد": "assert",
    "غير_متزامن": "async",
    "انتظر": "await",
    "كسر": "break",
    "صنف": "class",
    "استمر": "continue",
    "عرف": "def",
    "احذف": "del",
    "وإلا_إذا": "elif",
    "وإلا": "else",
    "استثناء": "except",
    "أخيراً": "finally",
    "من_أجل": "for",
    "من": "from",
    "عام": "global",
    "إذا": "if",
    "استورد": "import",
    "في": "in",
    "هو": "is",
    "لامدا": "lambda",
    "غير_محلي": "nonlocal",
    "ليس": "not",
    "أو": "or",
    "مرر": "pass",
    "ارفع": "raise",
    "ارجع": "return",
    "جرب": "try",
    "بينما": "while",
    "مع": "with",
    "أنتج": "yield",
    
    # Built-in Functions
    "أبس": "abs",
    "الكل": "all",
    "أي": "any",
    "أسكي": "ascii",
    "باين": "bin",
    "بول": "bool",
    "بايت_مصفوفة": "bytearray",
    "بايتس": "bytes",
    "قابل_للنداء": "callable",
    "شر": "chr",
    "طريقة_الصنف": "classmethod",
    "جمع": "compile",
    "مركب": "complex",
    "خواص": "dir",
    "خارج_القسمة": "divmod",
    "عد": "enumerate",
    "نفذ": "eval",
    "نفذ_كود": "exec",
    "فلتر": "filter",
    "عائم": "float",
    "تنسيق": "format",
    "مجموعة_مجمدة": "frozenset",
    "احصل_على_خاصية": "getattr",
    "عرف_خاصية": "hasattr",
    "هاش": "hash",
    "مساعدة": "help",
    "سداسي": "hex",
    "معرف": "id",
    "أدخل": "input",
    "عدد_صحيح": "int",
    "مثيل_من": "isinstance",
    "صنف_فرعي_من": "issubclass",
    "مكرر": "iter",
    "طول": "len",
    "قائمة": "list",
    "خريطة": "map",
    "أقصى": "max",
    "ذاكرة": "memoryview",
    "أدنى": "min",
    "التالي": "next",
    "كائن": "object",
    "ثماني": "oct",
    "افتح": "open",
    "رقم_أسكي": "ord",
    "قوة": "pow",
    "اطبع": "print",
    "خاصية": "property",
    "مجال": "range",
    "سلسلة_تمثيل": "repr",
    "معكوس": "reversed",
    "قرّب": "round",
    "مجموعة": "set",
    "عيّن_خاصية": "setattr",
    "شريحة": "slice",
    "مصفوفة_مرتبة": "sorted",
    "طريقة_ثابتة": "staticmethod",
    "سلسلة": "str",
    "مجموع": "sum",
    "سوبر": "super",
    "مجموعة_مرتبة": "tuple",
    "نوع": "type",
    "قيم": "vars",
    "زِب": "zip",
    "استورد_": "__import__",
    
    # Exceptions
    "استثناء_أساسي": "BaseException",
    "استثناء": "Exception",
    "توقف_دوري": "StopIteration",
    "توقف_تجنب": "StopAsyncIteration",
    "خطأ_حسابي": "ArithmeticError",
    "تقسيم_على_صفر": "ZeroDivisionError",
    "فيض": "OverflowError",
    "خطأ_نقطة_عائمة": "FloatingPointError",
    "خطأ_ذاكرة": "MemoryError",
    "اسم_غير_معرف": "NameError",
    "خطأ_منطق": "AssertionError",
    "خطأ_سمة": "AttributeError",
    "خطأ_مدخلات_مخرجات": "IOError",
    "خطأ_نظام": "OSError",
    "مفتاح_خطأ": "KeyError",
    "فهرس_خطأ": "IndexError",
    "خطأ_بناء_جملة": "SyntaxError",
    "خطأ_ترقيم": "IndentationError",
    "تاب_خطأ": "TabError",
    "نوع_خطأ": "TypeError",
    "قيمة_خطأ": "ValueError",
    "مرجع_خطأ": "ReferenceError",
    "خطأ_بيئة_التشغيل": "RuntimeError",
    "تحذير": "Warning",
}

# Additional dictionaries for standard library modules
MODULES = {
    "رياضيات": "math",
    "عشوائي": "random",
    "نظام": "sys",
    "نظام_تشغيل": "os",
    "مسار": "path",
    "وقت": "time",
    "تاريخ_وقت": "datetime",
    "جسون": "json",
    "إعادة": "re",
    "مجموعات": "collections",
    "تكرارات": "itertools",
    "وظائف": "functools",
    "نسخ": "copy",
    "نظام_ملفات": "os.path",
}

# Data types
TYPES = {
    "مصفوفة_بايت": "bytes",
    "مصفوفة_بايت_قابلة_للتعديل": "bytearray",
    "سلسلة_يونيكود": "str",
    "قائمة": "list",
    "مجموعة_مرتبة": "tuple",
    "مجموعة": "set",
    "مجموعة_مجمدة": "frozenset",
    "قاموس": "dict",
    "رقم_عائم": "float",
    "عدد_صحيح": "int",
    "عدد_مركب": "complex",
    "منطقي": "bool",
    "لا_شيء": "NoneType",
}