# arabicpy/__init__.py
"""
ArabicPython - Python programming language with Arabic keywords
"""

__version__ = "1.0.0"
__author__ = "Core JSC Team"

from .translator import translate, run, compile_to_py
from .translator_enhanced import KEYWORDS, MODULES, TYPES

__all__ = [
    'translate',
    'run',
    'compile_to_py',
    'KEYWORDS',
    'MODULES',
    'TYPES',
]