# setup.py
from setuptools import setup, find_packages # type: ignore

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="arabicpy",
    version="1.0.0",
    author="Core JSC Team",
    author_email="info@corejsc.com",
    description="Python programming language with Arabic keywords",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/CoreJSC/arabicpy",
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Natural Language :: Arabic",
        "Topic :: Education",
        "Topic :: Software Development",
    ],
    python_requires=">=3.6",
    entry_points={
        "console_scripts": [
            "arabicpy=arabicpy.cli:main",
        ],
    },
)